@@ -3,6 +3,7 @@ import numpy as np
 import requests
 import os
 import cv2
+import tqdm
 from quickocr.localization import model as localization_model
 from quickocr.recognition import model as recognition_model
 
@@ -13,14 +14,19 @@ def get_text(images: list, text_only=False, dist_dir='./output'):
     cfg.read_string(open(os.path.join(base_path, 'data', 'config.txt')).read())
 
     if not os.path.exists(os.path.join(base_path, 'data', 'recognition_weights.h5')):
+        print('download recognition_weights.h5')
+        weights = requests.get(cfg.get('recognition', 'url'))
         with open(os.path.join(base_path, 'data', 'recognition_weights.h5'), 'wb') as f:
-            weights = requests.get(cfg.get('recognition', 'url'))
-            f.write(weights.content)
+            for content in tqdm.tqdm(weights.iter_content()):
+                f.write(content)
 
     if not os.path.exists(os.path.join(base_path, 'data', 'localization_weights.h5')):
+        print('download localization_weights.h5')
+        weights = requests.get(cfg.get('localization', 'url'))
         with open(os.path.join(base_path, 'data', 'localization_weights.h5'), 'wb') as f:
-            weights = requests.get(cfg.get('localization', 'url'))
-            f.write(weights.content)
+            for content in tqdm.tqdm(weights.iter_content()):
+                f.write(content)
+
     for image_path in images:
         original_image = cv2.imread(image_path)
         bboxes = localization_model.get_text_localization(original_image, weights=os.path.join(base_path, 'data',
@@ -42,4 +48,4 @@ def get_text(images: list, text_only=False, dist_dir='./output'):
 
 
 if __name__ == '__main__':
-    get_text([r'E:\cdc\Project\Snapnews\opensource\test\1586743108.4626567.jpg'])
+    get_text([r'E:\cdc\Project\Snapnews\opensource\test\3192342.jpg'])
